==> ejc-report-impl-3.0.1-20210806.085119-9-sources.jar: com/ejianc/foundation/report/controller/param/GridHeader.java <==
package com.ejianc.foundation.report.controller.param;

import java.io.Serializable;

/**
 * 表头属性
 * 
 * @author guoming
 *
 */
public class GridHeader implements Serializable {

	private static final long serialVersionUID = -2043890697260188111L;

	private String id;

	private String code;

	private String name;

	private Boolean visible;

	private Boolean colFontBold;

	private Integer colFixed;

	private Integer showOrder;

	private String type;

	private Boolean innerFilter;

	private Long parentId;

	//数据格式话js函数
	private String formatter;

	//导出格式化
	private String exportFormat;

	//是否开启数据汇总
	private Boolean enableSummarize;

	//列对齐方式
	private String alignType;

	/**
	 * 列显示后缀
	 */
	private String suffixStr;

	/**
	 * 列背景色
	 */
	private String colBgColor;
	/**
	 * 列字体颜色
	 */
	private String colFontColor;

	/**
	 * 单据穿透：0-无穿透，1-固定地址穿透，2-规则穿透
	 */
	private String linkType;
	/**
	 * 穿透地址或穿透规则内容
	 */
	private String linkContent;

	public String getLinkType() {
		return linkType;
	}

	public void setLinkType(String linkType) {
		this.linkType = linkType;
	}

	public String getLinkContent() {
		return linkContent;
	}

	public void setLinkContent(String linkContent) {
		this.linkContent = linkContent;
	}

	public String getColBgColor() {
		return colBgColor;
	}

	public void setColBgColor(String colBgColor) {
		this.colBgColor = colBgColor;
	}

	public String getColFontColor() {
		return colFontColor;
	}

	public void setColFontColor(String colFontColor) {
		this.colFontColor = colFontColor;
	}

	public Boolean getColFontBold() {
		return colFontBold;
	}

	public void setColFontBold(Boolean colFontBold) {
		this.colFontBold = colFontBold;
	}

	public Integer getColFixed() {
		return colFixed;
	}

	public void setColFixed(Integer colFixed) {
		this.colFixed = colFixed;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getAlignType() {
		return alignType;
	}

	public void setAlignType(String alignType) {
		this.alignType = alignType;
	}

	public String getExportFormat() {
		return exportFormat;
	}

	public void setExportFormat(String exportFormat) {
		this.exportFormat = exportFormat;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Boolean getVisible() {
		return visible;
	}

	public void setVisible(Boolean visible) {
		this.visible = visible;
	}

	public Integer getShowOrder() {
		return showOrder;
	}

	public void setShowOrder(Integer showOrder) {
		this.showOrder = showOrder;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}

	public Boolean getEnableSummarize() {
		return enableSummarize;
	}

	public void setEnableSummarize(Boolean enableSummarize) {
		this.enableSummarize = enableSummarize;
	}
}

==> ejc-report-impl-3.0.1-20220803.082356-62-sources.jar: com/ejianc/foundation/report/controller/param/GridHeader.java <==
package com.ejianc.foundation.report.controller.param;

import java.io.Serializable;

/**
 * 表头属性
 * 
 * @author guoming
 *
 */
public class GridHeader implements Serializable {

	private static final long serialVersionUID = -2043890697260188111L;

	private String id;

	private String code;

	private String name;

	private Boolean visible;

	private Boolean colFontBold;

	private Integer colFixed;

	private Integer showOrder;

	private String type;

	private Boolean innerFilter;

	private Long parentId;

	//数据格式话js函数
	private String formatter;

	//导出格式化
	private String exportFormat;

	//是否开启数据汇总
	private Boolean enableSummarize;

	//列对齐方式
	private String alignType;

	/**
	 * 列显示后缀
	 */
	private String suffixStr;

	/**
	 * 列背景色
	 */
	private String colBgColor;
	/**
	 * 列字体颜色
	 */
	private String colFontColor;

	/**
	 * 单据穿透：0-无穿透，1-固定地址穿透，2-规则穿透
	 */
	private String linkType;
	/**
	 * 穿透地址或穿透规则内容
	 */
	private String linkContent;

	/**
	 * 字段说明
	 */
	private String colExtraInfo;

	public String getLinkType() {
		return linkType;
	}

	public void setLinkType(String linkType) {
		this.linkType = linkType;
	}

	public String getLinkContent() {
		return linkContent;
	}

	public void setLinkContent(String linkContent) {
		this.linkContent = linkContent;
	}

	public String getColBgColor() {
		return colBgColor;
	}

	public void setColBgColor(String colBgColor) {
		this.colBgColor = colBgColor;
	}

	public String getColFontColor() {
		return colFontColor;
	}

	public void setColFontColor(String colFontColor) {
		this.colFontColor = colFontColor;
	}

	public Boolean getColFontBold() {
		return colFontBold;
	}

	public void setColFontBold(Boolean colFontBold) {
		this.colFontBold = colFontBold;
	}

	public Integer getColFixed() {
		return colFixed;
	}

	public void setColFixed(Integer colFixed) {
		this.colFixed = colFixed;
	}

	public String getSuffixStr() {
		return suffixStr;
	}

	public void setSuffixStr(String suffixStr) {
		this.suffixStr = suffixStr;
	}

	public String getAlignType() {
		return alignType;
	}

	public void setAlignType(String alignType) {
		this.alignType = alignType;
	}

	public String getExportFormat() {
		return exportFormat;
	}

	public void setExportFormat(String exportFormat) {
		this.exportFormat = exportFormat;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Boolean getVisible() {
		return visible;
	}

	public void setVisible(Boolean visible) {
		this.visible = visible;
	}

	public Integer getShowOrder() {
		return showOrder;
	}

	public void setShowOrder(Integer showOrder) {
		this.showOrder = showOrder;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}

	public Boolean getEnableSummarize() {
		return enableSummarize;
	}

	public void setEnableSummarize(Boolean enableSummarize) {
		this.enableSummarize = enableSummarize;
	}

	public String getColExtraInfo() {
		return colExtraInfo;
	}

	public void setColExtraInfo(String colExtraInfo) {
		this.colExtraInfo = colExtraInfo;
	}
}
